@@ -1,4 +1,4 @@
-module javax.jws {
+module java.jws {
     exports javax.jws;
     exports javax.jws.soap;
 
